package f00f.net.irc.martyr;

import java.util.Observable;
import java.util.Observer;

import f00f.net.irc.martyr.commands.JoinCommand;
import f00f.net.irc.martyr.commands.KickCommand;

/**
 * <p>AutoJoin joins a group if the IRCConnection is ready.  It will wait until
 * it is ready if it is not (by waiting for the REGISTERED state change).</p>
 *
 * <p>AutoJoin maintains a persistent Join (re-join if kicked).
 * AutoJoin can cease to be persistent by calling the 'disable'
 * method.</p>
 */
public class AutoJoin extends GenericAutoService
{

private String channel = null;

public AutoJoin( IRCConnection connection, String channel )
{
	super( connection );
	
	this.channel = channel;

	enable();
}

protected void updateState( State state )
{

	if( state == State.REGISTERED )
		performJoin();
}

protected void updateCommand( Command command_o )
{
	if( command_o instanceof KickCommand )
	{
		KickCommand kickCommand = (KickCommand)command_o;

		if( kickCommand.kickedUs( getConnection().getClientState() ) )
		{
			getConnection().sendCommand( new JoinCommand( kickCommand.getChannel() ) );
		}
	}	
}

private void performJoin()
{
	getConnection().sendCommand( new JoinCommand( channel ) );
}

// END AutoResponder
}
 


 
