package f00f.net.irc.martyr;

import java.util.Observable;
import java.util.Observer;

import f00f.net.irc.martyr.commands.PingCommand;
import f00f.net.irc.martyr.commands.PongCommand;

/**
 * AutoResponder is where commands that should be auto-responded (such
 * as PING-PONG) should go.
 */
public class AutoResponder implements Observer
{

private IRCConnection connection;
private boolean enabled = false;

public AutoResponder( IRCConnection connection )
{
	this.connection = connection;
	enable();
}

public void enable()
{
	if( enabled )
		return;

	connection.addCommandObserver( this );
	enabled = true;
}

public void disable()
{
	if( !enabled )
		return;
		
	connection.removeCommandObserver( this );
	enabled = false;
}

public void update( Observable observer, Object updated )
{

	if( updated instanceof PingCommand )
	{
		// We need to do some pongin'!
		PingCommand ping = (PingCommand)updated;

		String response = ping.getPingSource();

		connection.sendCommand( new PongCommand( response ) );
	}
}

// END AutoResponder
}
 


 
