package f00f.net.irc.martyr;

import java.util.Observer;
import java.util.Observable;

/**
 * ClientStateMonitor asks commands to update the client state.
 */
public class ClientStateMonitor implements Observer
{

private IRCConnection connection;

private boolean enabled = false;

/**
 * This should only be called by the IRCConnection itself.
 */
ClientStateMonitor( IRCConnection connection )
{
	this.connection = connection;

	enable();
}

public void enable()
{
	if( enabled )
		return;
	enabled = true;

	connection.addCommandObserver( this );
}

public void disable()
{
	if( !enabled )
		return;
	connection.removeCommandObserver( this );
	enabled = false;
}

public void update( Observable observable, Object command_o )
{
	Command command = (Command)command_o;
	
	if( command.updateClientState( connection.getClientState() ) )
		Debug.println( "ClientStateMonitor", "Client state updated", Debug.NORMAL );
	
}

// ===== END ClientStateMonitor
}

