package f00f.net.irc.martyr;

import f00f.net.irc.martyr.clientstate.ClientState;

/**
 * Defines what a command is.  All errors are commands.
 */
public interface Command
{

/**
 * Some commands, when received by the server, can only occur in one
 * state.  Thus, when this command is received, the protocol should
 * assume that it is that state.  A command can use the 'unknown'
 * state to indicate it can be received in any state (for example,
 * ping).
 */
State getState();

/**
 * Every command should know how to register itself (or not) with the
 * command parsing engine.
 */
void selfRegister( CommandRegister commandRegister );

/**
 * Forms a string appropriate to send to the server, if required.
 * Most errors will have no such string, as they are received and not
 * sent.
 */
String render();

/**
 * Parses a string and produces a formed command object, if it can.
 * Should return null if it cannot form the command object.  The
 * identifier is usually ignored, in the special case that commands
 * can be identified by multiple identifiers, that might be important.
 */
Command parse( String prefix, String identifier, String params );

/**
 * Gives the command a copy of the raw string from the server.  Called
 * by IRCConnection after the command is parsed.
 */
void setSourceString( String str );

/**
 * Allows a third party to receive a copy of the raw string.
 */
String getSourceString();

/**
 * Asks the command to ensure that information it knows about the
 * state the server thinks the client is in matches what we have.
 * Returns true if state changes were made.
 */
boolean updateClientState( ClientState state );

}




