package f00f.net.irc.martyr;

import java.util.Hashtable;

import f00f.net.irc.martyr.commands.*;
import f00f.net.irc.martyr.errors.*;
import f00f.net.irc.martyr.replies.*;

/**
 * CommandRegister is basically a big hashtable that maps IRC
 * identifiers to command objects that can be used as factories to
 * do self-parsing.  CommandRegister is also the central list of
 * commands.
 */
public class CommandRegister
{

private Hashtable commands;
public CommandRegister()
{
	commands = new Hashtable();

	// Note that currently, we only have to register commands that
	// can be received from the server.
	new PingCommand().selfRegister( this );
	new NickCommand().selfRegister( this );
	new JoinCommand().selfRegister( this );
	new KickCommand().selfRegister( this );
	new NoticeCommand().selfRegister( this );
	new MessageCommand().selfRegister( this );
	new TopicCommand().selfRegister( this );

	// Register errors
	new NickInUseError().selfRegister( this );

	// Register replies
	new LUserMeReply().selfRegister( this );
	new LUserOpReply().selfRegister( this );
	new LUserClientReply().selfRegister( this );
}

public void addCommand( String ident, Command command )
{
	commands.put( ident, command );
}

public Command getCommand( String ident )
{
	return (Command)commands.get( ident );
}

}

