package f00f.net.irc.martyr;

import java.io.PrintStream;

/**
 * Aids in debugging and logging for martyr.
 */
public class Debug
{

/**
 * Signals in internal fault, similar to failling an assertion but
 * the program doesn't halt.
 */
public static final int FAULT = 0;
/**
 * Something went wrong, maybe not our fault.
 */
public static final int CRITICAL = 5;
/**
 * Information about normal procedures.
 */
public static final int NORMAL = 10;
/**
 * Information about some details of normal procedures.
 */
public static final int VERBOSE = 15;
/**
 * Excessive information about internals that no human should need to
 * know or care about.
 */
public static final int EXCESSIVE = 20;

// Defaults
private static PrintStream out = System.out;
private static int level = EXCESSIVE;

/**
 * Sets the output stream to where the debug messages will go.
 */
public synchronized static void setOutputStream( PrintStream out )
{
	Debug.out = out;
}

/**
 * Sets the debug level so that all messages equal to or less than
 * 'level' will be output.
 */
public synchronized static void setDebugLevel( int level )
{
	Debug.level = level;
}

/**
 * Writes out the message if msgLevel is less than or equal to the
 * internal level.
 */
public synchronized static void println( String sender, String message, int msgLevel )
{
	if( msgLevel <= level )
	{
		if( sender != null )
			out.println( sender + ": " + message );
		else
			out.println( message );
	}
}

public static void println( Object sender, String message, int msgLevel )
{
	println( sender.toString(), message, msgLevel );
}

}

