package f00f.net.irc.martyr;

import java.util.Observable;
import java.util.Observer;

/**
 * Provides a framework for an auto service.  Does not enable by default.
 * Splits the 'update' method into two, 'updateState' and 'updateCommand'.
 * Also provides thread safety on all methods.
 */
public class GenericAutoService implements Observer
{

private boolean enabled = false;
private IRCConnection connection;

protected GenericAutoService( IRCConnection connection )
{
	this.connection = connection;
}

public synchronized void enable()
{
	if( enabled )
		return;

	connection.addStateObserver( this );
	connection.addCommandObserver( this );
	enabled = true;
}

public synchronized void disable()
{
	if( !enabled )
		return;
		
	connection.removeStateObserver( this );
	connection.removeCommandObserver( this );
	enabled = false;
}

public synchronized void update( Observable observer, Object updated )
{

	if( updated instanceof State )
		updateState( (State)updated );
	else if( updated instanceof Command )
		updateCommand( (Command)updated );
	else
	{
		Debug.println( this, "Unknown object given to update.", Debug.FAULT );
	}
}

protected IRCConnection getConnection()
{
	return connection;
}

protected synchronized boolean isEnabled()
{
	return enabled;
}

protected void updateState( State state )
{
}

protected void updateCommand( Command command )
{
}


// END AutoRegister
}
 


 
