package f00f.net.irc.martyr.commands;

import f00f.net.irc.martyr.State;
import f00f.net.irc.martyr.Command;
import f00f.net.irc.martyr.Debug;
import f00f.net.irc.martyr.CommandRegister;
import f00f.net.irc.martyr.clientstate.ClientState;
import f00f.net.irc.martyr.clientstate.Channel;
import f00f.net.irc.martyr.util.FullNick;


/**
 * Defines JOIN command.
 */
public class JoinCommand extends GenericCommand
{

private String channel;
private FullNick user;

/** For use as a factory */
public JoinCommand()
{
	this( null, null );
}

public JoinCommand( FullNick user, String channel )
{
	this.user = user;
	this.channel = channel;
}

public JoinCommand( String channel )
{
	this( null, channel );
}

public Command parse( String prefix, String identifier, String params )
{
	return new JoinCommand( new FullNick( prefix ), getParameter( params, 0 ) );
}

public String getIrcIdentifier()
{
	return "JOIN";
}

public String renderParams()
{
	return channel;
}

public String getChannel()
{
	return channel;
}

public FullNick getUser()
{
	return user;
}

public boolean updateClientState( ClientState state )
{
	System.out.println( "Nick: " + state.getNick().toString() );
	if( user.equals( state.getNick() ) )
	{
		// We've joined a group.
		Debug.println( "JOIN", "We've joined " + channel, Debug.VERBOSE );
		state.addChannel( channel );
		return true;
	}
	else
	{
		// Someone else joined the group.
		Debug.println( "JOIN", "" + user + " joined " + channel, Debug.VERBOSE );
		// 1) Grab group
		Channel channelObj = state.getChannel( channel );
		// 2) Add user
		channelObj.addUser( user.getNick() );
		return true;
	}
}
	

}


