package f00f.net.irc.martyr.commands;

import f00f.net.irc.martyr.State;
import f00f.net.irc.martyr.Command;
import f00f.net.irc.martyr.Debug;
import f00f.net.irc.martyr.clientstate.ClientState;
import f00f.net.irc.martyr.util.FullNick;


/**
 * Defines the PRIVMSG command.  Messages can be sent to groups or to users.
 */
public class MessageCommand extends GenericCommand
{

private FullNick from;
private String dest;
private String message;


/** Factory */
public MessageCommand()
{
	from = null;
	dest = null;
	message = null;
}

public MessageCommand( String dest, String message )
{
	this( null, dest, message );
}

public MessageCommand( FullNick dest, String message )
{
	this( dest.getNick(), message );
}

public MessageCommand( FullNick source, String dest, String message )
{
	this.from = source;
	this.dest = dest;
	this.message = message;
}

/**
 * Parses a string and produces a formed command object, if it can.
 * Should return null if it cannot form the command object.
 */
public Command parse( String prefix, String identifier, String params )
{
	return new MessageCommand( 
		new FullNick( prefix ),
		getParameter( params, 0 ),
		getParameter( params, 1 )
	);
}

/**
 * Returns the string IRC uses to identify this command.  Examples:
 * NICK, PING, KILL, 332
 */
public String getIrcIdentifier()
{
	return "PRIVMSG";
}

/**
 * Renders the parameters of this command.
 */
public String renderParams()
{
	return dest + " :" + message;
}

public FullNick getSource()
{
	return from;
}

public String getDest()
{
	return dest;
}

public String getMessage()
{
	return message;
}

/**
 * Returns true if the message is both private and for us.
 */
public boolean isPrivateToUs( ClientState state )
{
	return state.getNick().equals( dest );
}

}


