package f00f.net.irc.martyr.commands;

import f00f.net.irc.martyr.State;
import f00f.net.irc.martyr.Command;
import f00f.net.irc.martyr.Debug;
import f00f.net.irc.martyr.CommandRegister;
import f00f.net.irc.martyr.clientstate.ClientState;
import f00f.net.irc.martyr.util.FullNick;

/**
 * Defines NICK command.
 */
public class NickCommand extends GenericCommand
{

private FullNick oldNick;
private FullNick newNick;

/** For use as a factory */
public NickCommand()
{
	this( null, null );
}

public NickCommand( FullNick oldNick, FullNick newNick )
{
	this.oldNick = oldNick;
	this.newNick = newNick;
}

public NickCommand( String newNick )
{
	this( null, new FullNick( newNick ) );
}

public Command parse( String prefix, String identifier, String params )
{
	return new NickCommand( new FullNick( prefix ), new FullNick ( getParameter( params, 0 ) ) );
}

public String getIrcIdentifier()
{
	return "NICK";
}

public String renderParams()
{
	return getNick();
}

public String getNick()
{
	return newNick.getNick();
}

public boolean updateClientState( ClientState state )
{
	// Does this apply to us?
	if( oldNick.equals( state.getNick() ) )
	{
		state.setNick( newNick );
		return true;
	}
	return false;
}

}


