package f00f.net.irc.martyr.util;

import java.util.StringTokenizer;

/**
 * Parses out a full nick (ex: sork!sork@f00f.net) and stores it for use.
 */
public class FullNick
{

private String nick;
private String user;
private String remotehost;

private String original;

public FullNick( String original )
{
	this.original = original;
	parse( original );
}


/**
 * It can't deal with parameters that have no '!'.  When given a parameter with
 * no '!', it simply places the entire string into the 'nick' field.  FullNick
 * is intended to be immutable.
 *
 * TODO: Should this enforce proper nick syntax?
 */
private void parse( String original )
{
	if( original == null )
		return;

	StringTokenizer tokens = new StringTokenizer( original, "!" );

	nick = tokens.nextToken();

	if( tokens.hasMoreTokens() )
		user = tokens.nextToken("@");

	if( tokens.hasMoreTokens() )
		remotehost = tokens.nextToken("");
}

public String getNick()
{
	return nick;
}

public String getUser()
{
	return user;
}

public String getHost()
{
	return remotehost;
}

/**
 * Performs case insesitive equals on the nicks only.  Should it be more RFC
 * stringent?  ({ == [ and ] == } and | == \)
 */
public boolean equals( String nick )
{
	return nick.equalsIgnoreCase( this.nick );
}

public boolean equals( FullNick nick )
{
	return equals( nick.getNick() );
}

public boolean equals( Object object )
{
	return false;
}

public String toString()
{
	return nick;
}

/**
 * Unit test.
 */
public static void main( String args[] )
{

	FullNick nick = new FullNick( args[0] );

	System.out.println( nick.getNick() );
	System.out.println( nick.getUser() );
	System.out.println( nick.getHost() );
	
	if( args.length > 1 )
	{

		FullNick nick2 = new FullNick( args[1] );
		
		System.out.println( "" );
		System.out.println( nick2.getNick() );
		System.out.println( nick2.getUser() );
		System.out.println( nick2.getHost() );
	
		System.out.println( nick2.equals( nick ) ? "Equal." : "Not equal." );
	
	}
}

}


